Questions from an anonymous poster | Fight © Trolls
Description: An anonymous poster (presumably John Steele, based on the hallmark "your" and some other hints), posted (mostly) polite discussion questions on 11/21/2012. When it is not vitriol and trolling, I al...
Date: 2012-11-22T04:51:54+00:00

# Questions from an anonymous poster

An anonymous poster (presumably John Steele, based on the hallmark “your” and some other hints), posted (mostly) polite discussion questions on 11/21/2012. When it is not vitriol and trolling, I always ready to keep a civil discussion.

The same set of questions was posted on Rob Cashman’s and DieTrollDie’s blogs.

So, the questions.

> There is a lot of hyperbole, anger, and creative pictures out there regarding copyright litigation. Is there a few things we can agree on?

> 10 Points that should be automatically agreed to by everyone
> 1. Copyright infringement is against the law and covered by Title 17 of the US Code.

> 2. People that do actually commit copyright infringement (pirates) are wrong and according to our laws, liable.

> 3. Being named in a lawsuit does not mean that you are a pirate, just that your alleged to be one.

> 4. Pirates are not going to report themselves to the copyright holders on their own.

> 5. There is disagreement over whether the current laws are fair to pirates and alleged pirates.

> 6. Plainitff’s attorneys are not expected to have all the evidence necessary to win their case the moment they file the complaint, including attorneys that represent copyright holders (trolls).

> 7. IP address are not people, nor does irrefutable proof exist via ones ISP that if an IP address is observed illegally downloading infringing material, that means the subscriber of the internet account with that IP address is liable.

> 8. No one likes to be involved as a defendant in copyright infringement cases.

> 9. It is possible for someone to be named in a copyright litigation case that did not personally download the copyrighted material.

> 10. #9 does not mean all cases involving copyrighted content should be disallowed. Otherwise, any type of case in which a defendant has ever won should never be allowed to be filed again, including ever criminal charge in history.

> 11. The legal system does not allow people to appear anonymously unless granted leave to do so first by the court.

> 12. Legally produced porn, and adult content owners, deserve the same constitutional rights that other companies receive, and should not be discriminated against because of what they produce.

> 13. There is a method for changing laws you don’t agree with. Part of that process occurred earlier this month on the 6th.

> 14. If a defendant in a case states he didn’t do whatever he is being accused of, the Plaintiff is not required to drop the case.

> 15. Pre-suit litigation is favored by every judicial branch in the US, including the United States Supreme Court who has been clearly articulating that central premise since 1898.

> 5 points that trolls think is accurate, that almost every attorney will agree with, but that pirates may not agree with:

> 1. Discovery in America is liberal, and all that is required to receive the requested information is for that information to reasonably lead to relevant information. In other words, even if the subscriber is not the pirate, if knowing who the subscriber is might reasonably lead to knowing who the pirate is, then the subscribers information is discoverable.

> 2. To date, piracy is hurting entire industries, and if everyone can get away with stealing content rather than paying for it with NO risk of getting caught, piracy will increase or at least continue to be very high.

> 3. Whether or not you agree with the laws, they are the laws. You do not get to pick and choose which laws to follow AND get to pick whether the consequences apply.

> 4. If content producers receive money from a pirate through litigation, or pending litigation, it is legally permissible. Granted, almost every pirate and pirate friendly site does not like that producers might make money from copyright litigation, but this dislike is based on subjective hate of porn producers and trolls, and not based on the law.

> 5. If the content being stolen was a non-profit film on caring for sick children, and any settlement money received went to the Red Cross, pirates would
> still be upset about having to pay anything if they were caught

My answers (initially posted as a reply) are divided one per comment below to facilitate discussion (Rob Cashman’s idea).

- Tweet
- Share on Tumblr
- More

- Flattr
- Email

### Like this:

Like Loading...

### Discussion

## 27 responses to ‘Questions from an anonymous poster’

1. Well, (mostly) politely asked questions warrant answers. There are too many questions, some are rhetorical and some disingenuously formulated, so I’ll be rather short and sometimes cryptic.

   10 Points that should be automatically agreed to by everyone

   > 1. Copyright infringement is against the law and covered by Title 17 of the US Code.

   Agree.

   Reply

2. > 2. People that do actually commit copyright infringement (pirates) are wrong and according to our laws, liable.

   “wrong” is an ambiguous and relative term, otherwise agree — liable, yes.

   Reply

3. > 3. Being named in a lawsuit does not mean that you are a pirate, just that your alleged to be one.

   Agree: does not mean. There are more reasons than the “alleged one” though: vindication of Erin, for example.

   Reply

4. > 4. Pirates are not going to report themselves to the copyright holders on their own.

   Rhetorical question and does not warrant an answer as such.

   Reply

   - 4.1 People who criminally extort others are not going to turn themselves into the police, or to the District Attorney. A funny thing about criminal extortion, if an attorney does it, he can lose the license to practice law.

     Reply

5. > 5. There is disagreement over whether the current laws are fair to pirates and alleged pirates.

   Society as a whole is pretty much in consensus. Warnings, fines < $100. Small groups who disagree are those who 1) think (regardless if it is true or not, but it is irrelevant for the purpose of this question) that piracy is seriously harms their businesses 2) and the ones who profit from infringement. The former group advocates softer laws than the latter, even it is counter-intuitive at the first glance.

   Reply

6. > 6. Plainitff’s attorneys are not expected to have all the evidence necessary to win their case the moment they file the complaint, including attorneys that represent copyright holders (trolls).

   Agree, that’s how civil process works. Nonetheless, normal litigation fixes this deficiency later in the process, while trolling is a pure bluff, i.e. the practice described in this statement is abused. There is never comes to light of day though because “later in the process” usually never happens.

   Reply

7. > 7. IP address are not people, nor does irrefutable proof exist via ones ISP that if an IP address is observed illegally downloading infringing material, that means the subscriber of the internet account with that IP address is liable.

   Agree.

   Reply

8. > 8. No one likes to be involved as a defendant in copyright infringement cases.

   A masochist would disagree.

   Reply

9. > 9. It is possible for someone to be named in a copyright litigation case that did not personally download the copyrighted material.

   Agree, and it happens pretty often. 30% is a going rate.

   Reply

10. > 10. #9 does not mean all cases involving copyrighted content should be disallowed. Otherwise, any type of case in which a defendant has ever won should never be allowed to be filed again, including ever criminal charge in history.

    All cases should not be disallowed. Clearly abusive ones should.

    Reply

11. > 11. The legal system does not allow people to appear anonymously unless granted leave to do so first by the court.

    Formally – no, but there are many instances when judges allowed it.

    Reply

    - The legal system allows people to appear under fake names, given that the court does not suspect that the name in question is fake. Once the court learns about the fraud, the consequences for defendants will be dire.

      The same is applicable to plaintiffs. Once the court realizes that “Guava”, “Arte de Oaxaca”, “AF Holdings” and “Ingenuity 13” are bogus, fraudulent corporations, federal criminal investigation ensues.

      Reply

12. > 12. Legally produced porn, and adult content owners, deserve the same constitutional rights that other companies receive, and should not be discriminated against because of what they produce.

    Commented above. In addition, if porn ever will be discriminated, it will be solely because of trolls: society granted important tool to pornographers, and it was abused: society can take it back.

    Reply

    - Original comment (mind that the questins were posted on the Guava page) was:

      > 12. Legally produced porn, and adult content owners, deserve the same constitutional rights that other companies receive, and should not be discriminated against because of what they produce.

      > Legally? Funny that you picked this particular page for your mental farts: you should know that the subject of this page deals with porn illegally produced porn in a mansion on the outskirts of Phoenix. Producing pornography is illegal in Arizona.

      Reply

13. > 13. There is a method for changing laws you don’t agree with. Part of that process occurred earlier this month on the 6th.

    Agree. Another way is to utilize my First Amendment rights to spread awareness and, as a result, affect case law. Which I’m doing somewhat successfully.

    Reply

14. > 14. If a defendant in a case states he didn’t do whatever he is being accused of, the Plaintiff is not required to drop the case.

    Agree: denial was never a proof of innocence, although it is slightly irrelevant here: defendant shouldn’t make any affirmative statements at this stage, it is up to plaintiff to prove the tort.

    Reply

    - 14. Not required, but plaintiff opens itself up to a malicious prosecution lawsuit if it does not have any evidence that says otherwise. And no, an IP address is not evidence.

      Reply

15. > 15. Pre-suit litigation is favored by every judicial branch in the US, including the United States Supreme Court who has been clearly articulating that central premise since 1898.

    Normal litigation, yes. But what is smuggled by disguise of normal litigation is extortion (actually I’ll try to avoid using charged and incorrect words, correct terms are “racket” and “blackmail”). There were instances of somewhat fair “pre-litigation: Fantalis comes to mind, but 99% defendants are in unfair disadvantage for multiple reasons. We are here to heal this unfairness via education.

    Reply

16. 5 points that trolls think is accurate, that almost every attorney will agree with, but that pirates may not agree with:

    > 1. Discovery in America is liberal, and all that is required to receive the requested information is for that information to reasonably lead to relevant information. In other words, even if the subscriber is not the pirate, if knowing who the subscriber is might reasonably lead to knowing who the pirate is, then the subscribers information is discoverable.

    Not ready to discuss.

    Reply

17. > 2. To date, piracy is hurting entire industries, and if everyone can get away with stealing content rather than paying for it with NO risk of getting caught, piracy will increase or at least continue to be very high.

    Closing my eyes on disingenuous use of the term “stealing,” I’d say rather yes, industries lose from free flow of material, but it is irrelevant, because this is rather an objective flow of history and not fixable by sole enforcement. Even more, increasing endorsement is counterproductive in the long run. In short run, trolls’ pockets are stuffed and people can suffer, that’s it.

    Reply

    - forcing an industry(s) to change, though it may drop profits, does not necessarily hurt them…..a lot of cases of piracy have been shown to happen directly because of lack of online access. if a tv/film company does not offer one of their shows/films online then VERY OFTEN those are the items being pirated. also the argument that 1 dl’d copy==1 lost sale is false on so many levels. does theft hurt EVERY INDUSTRY?? why yes, but the cost of getting caught stealing a $20 shirt is often times $20, if charges are pressed the fine is under $500 is almost every state, in the case of copyright no lost goods are involved in the infringement, so it does not directly harm in the same way that actually theft of tangible goods does, and yet the fine can be over $150000.00 for one copied item…..fighting tyrannical laws is not just in our nature, but it is in our history and in our very culture as Americans. this country was formed by breaking tyrannical laws…..

      Reply

    - “piracy is hurting entire industries”
      Assumes facts not in evidence. Unbiased reports of the “damages” cause to these industries have numbers significantly lower than the industry claims. The industries game the system early and often to inflate the numbers to silly proportions. Don’t forget employee’s of grocery stories are considered to be a part of IP intensive industry now.
      Piracy leads to more sales, this is fact and has been verified.
      People want to sample the product and if they like it they will purchase it, or more in the same line. If they dislike it they delete it and move on.

      “stealing”
      Please show me vanishing product everytime a copy is made, or find a more suitable term not loaded to bias the person hearing the message.

      “piracy”
      Maybe not name it after something really cool. Pirates are trendy.
      http://www.rockpapercynic.com/index.php?date=2012-04-09

      If the industries are so hurt, why have no players failed?

      Thanks for playing… buhbye

      Reply

18. > 3. Whether or not you agree with the laws, they are the laws. You do not get to pick and choose which laws to follow AND get to pick whether the consequences apply.

    Laws are laws, alas. Even the most ridiculous laws (like illegality of producing pornography in Arizona) must be followed. Saying that, everyone chooses myriad of laws he or she breaks every day. Light drugs at parties, speeding, not turning headlights when raining etc. Show me one without sin… I don’t want even start talking about the necessity of law breaking for a healthy society. Giordano Bruno was a criminal, no doubt. Defying obsolete and unfair copyright laws may or may not be heroic, depends on circumstances. It’s a huge topic, and I clearly not for today.

    Reply

19. > 4. If content producers receive money from a pirate through litigation, or pending litigation, it is legally permissible. Granted, almost every pirate and pirate friendly site does not like that producers might make money from copyright litigation, but this dislike is based on subjective hate of porn producers and trolls, and not based on the law.

    This is called “misuse of copyright.” Trolling has nothing to do with legit litigation and recover. Tell me about 100% return on investment… or max statutory rate exceeded multiple times. Even if it looks legal at he first glans, there are so many problems with this MO, that it’s a field day for an experienced lawyer.

    Dislike is based on objective abuse of the spirit of law, exploring loopholes that are contrary to societal standards. Hatred for porn producers as enables of that abuse is secondary. Disregard of societal norms (zero empathy) also plays an important role in disgust of society towards trolls.

    Reply

20. > 5. If the content being stolen was a non-profit film on caring for sick children, and any settlement money received went to the Red Cross, pirates would still be upset about having to pay anything if they were caught

    The content is irrelevant. Methods of monetizing infringement are disgusting regardless of content.

    I would ask a number of questions about validity of copyrights, standing to sue, forging signatures, illegality of robocalls etc, but I’m sleepy and want to go to bed earlier today. Hope that someone else will articulate our set of questions and/or expand my answers.

    Reply

21. This is just DISINFORMATION, no matter which troll wrote this. It is a mixture of truisms (“No one likes to be involved as a defendant…”), semi-relevant observations, and misrepresentation. These blunted troll points were never really for discussion or common ground. They’re intended to trick those less familiar with the situation.

    If this is such a righteous battle, John and other scamsters, how come it’s mainly being waged apparently on behalf of porn purveyors?

    If there is such concern about content producers, Mr. Attorney Troll, please disclose the net percentage of the settlements that the porn purveyors receive. Who is getting the bulk of the settlement money?

    Should the U.S. civil justice system be derailed to this extent? More than a third of all Federal copyright cases for 2 years and counting are aimed at extorting uninformed folk, on behalf of porn purveyors, regardless of innocence, accuracy, or evidence.

    Practically speaking, constituencies are under-represented all the time. Is it really a public service to over-represent in civil court the apparent interests of “creative” businesses enthusiastically depicting, for instance, forced anal intercourse or brutal treatment of carnal participants? Is it necessary to immorally abuse the justice system for this or any greedy group?

    Reply

### Leave a Reply Cancel reply

Enter your comment here...

Fill in your details below or click an icon to log in:

Email (Address never made public)
Name
Website

You are commenting using your WordPress.com account. ( Log Out / Change )

You are commenting using your Twitter account. ( Log Out / Change )

You are commenting using your Facebook account. ( Log Out / Change )

You are commenting using your Google+ account. ( Log Out / Change )

Cancel

Connecting to %s

Notify me of new comments via email.

Notify me of new posts via email.

Follow

### Follow “Fight © Trolls ”

Get every new post delivered to your Inbox.

Join 5,977 other followers

Build a website with WordPress.com
Send to Email Address Your Name Your Email Address
Cancel
Post was not sent - check your email addresses!
Email check failed, please try again
Sorry, your blog cannot share posts by email.
%d bloggers like this: